@@ -8,7 +8,6 @@ from .base import StreamObject
 from .settings import (
     BLOCK_OPTIONS, 
     SHOW_ADMIN_HELP_TEXT, 
-    SHOW_ADMIN_COLLAPSE,
     DELETE_BLOCKS_FROM_DB, 
     BASE_ADMIN_URL
     )
@@ -39,7 +38,6 @@ class StreamFieldWidget(Widget):
         
         attrs["model_list_info"] = json.dumps(model_list_info)
         attrs['show_admin_help_text'] = SHOW_ADMIN_HELP_TEXT
-        attrs['show_admin_collapse'] = SHOW_ADMIN_COLLAPSE
         attrs['delete_blocks_from_db'] = DELETE_BLOCKS_FROM_DB
         attrs['base_admin_url'] = BASE_ADMIN_URL
         super().__init__(attrs)
@@ -91,6 +89,11 @@ class StreamField(JSONField):
             value = value.value
         return json.dumps(value)
 
+    def get_db_prep_value(self, value, connection, prepared=False):
+        if value and isinstance(value, StreamObject):
+            value = value.value
+        return super().get_db_prep_value(value, connection, prepared)
+
     def value_to_string(self, obj):
         value = self.value_from_object(obj)
         return value.value
